;+
; NAME:
;       READ_TRACE_FOV
; PURPOSE:
;       Reads selected sub-image, etc. from TRACE data files
; CATEGORY:
; CALLING SEQUENCE:
;	read_trace_fov, files, ss, index, data
;	read_trace_fov, struct, ss, index, data
; INPUTS:
;       files or struct		either:
;				1) list of files OR
;				2) structure with catalog records
;	ss			vector of images in files
; OPTIONAL INPUT PARAMETERS:
; KEYWORD INPUT PARAMETERS:
;	sub_frame 		Array defining limits of subframe (x0,y0,x1,y1)
;	cadence			Desired image cadence (in minutes)
; OUTPUTS:
; OPTIONAL OUTPUT PARAMETERS:
; KEYWORD OUTPUT PARAMETERS:
; COMMON BLOCKS:
; SIDE EFFECTS:
;       Displays image
; RESTRICTIONS:
;	Cadence not full implimented!!!
;	Section between ;******* should be replaced by call to upgraded read_trace
; PROCEDURE:
;
; MODIFICATION HISTORY:
;          Oct-98  RDB  Written
;
;-

pro	read_trace_fov, struct, qq, index, data, $
		subframe=subframe, cadence=cadence

;help,struct

if datatype(struct) eq 'STC' then begin
   files = trace_struct2filename(struct(qq),/hourly)
   ss = struct(qq).image_ss
endif else begin
   files = struct
   ss = qq
endelse

help,files,ss
ff = findfile('$TRACE_I1_DIR/week*/'+files(0))
print,ff

if not keyword_set(subframe) then begin
;	need to display subframe and have user select outline

;	use frame 0, should this be selectable???
;;   ff = findfile('$TRACE_I1_DIR/week*/'+files(0))
;;   print,ff
   read_trace,ff,ss(0),index,data,outsiz=512 ;<<<<<<<<<
   sdata = trace_scale(index,data,/despike,/byte)
   pmm,sdata
   wdef,im=sdata
   tv,sdata

;	??? don't understand value I have to put in color!!
   box_cursor, x0dv, y0dv, nxdv, nydv, color=100	;returns device coords
;    print,x0dv,y0dv,nxdv,nydv
   sfact = index.naxis1/512
   print,'Display scale factor:',sfact
   x0 = x0dv*sfact & nx = nxdv*sfact
   x1 = x0 + nx
   y0 = y0dv*sfact & ny = nydv*sfact
   y1 = y0 + ny 

   draw_boxcorn, x0dv, y0dv, x0dv+nxdv, y0dv+nydv	;, /data
;	should dimensions be rounded???

endif else begin
;	sub-framme coordinates are supplied

   x0 = subframe(0)
   x1 = subframe(1)
   y0 = subframe(2)
   y1 = subframe(3)
   nx = x1-x0
   ny = y1-y0

   read_trace,ff,ss(0),index			;need a sample struct

;	should dimensions be rounded???
endelse

   print, 'X Range: ', x0, x1, nx
   print, 'Y Range: ', y0, y1, ny

;	select frames at a given cadence
if keyword_set(cadence) then begin
;	grid_data!! - can only work if structure available??
new_ss = grid_data(struct(qq),min=cadence)
help,new_ss
print,qq,qq(new_ss)
;	need to redo ss and files!!!
print,trace_list_index(struct(qq(new_ss)))
box_message,'CADENCE NOT yet fully implimented'
endif

;	exclude SAA and HLZ's ????

;	nframe may be different because of cadence!!
nframe = n_elements(ss)

box_message,'No of images will be:'+string(nframe)
cont=''
read,'Continue: ',cont
if strmid(strupcase(cont),0,1) ne 'Y' then begin
   index = -1 & data = -1
   return
endif

;
;	THIS SECTION SHOULD BE REPLACE BY CALL TO UPGRADED READ_TRACE
;****************************************************************
;	make output data arrays
data = intarr(nx,ny,nframe)
index = replicate(index,nframe)
;help,index,data

for jf=0,nframe-1 do begin

   read_trace,'$TRACE_I1_DIR/week*/'+files(jf),ss(jf),iidx,idata
   print,'>>> ',jf,ss(jf),files(jf),fmt_tim(iidx),format='(a,i4,i6,3x,a,3x,a)'

   data(*,*,jf) = idata(x0:x1-1,y0:y1-1)
;   help,iidx,idata
;   help,idata(x0:x1-1,y0:y1-1)

;       adjust the pointing in the index!!!!
;???   iidx.crval1, .crval2
   nwxc = iidx.xcen + ((x0+nx/2.)-iidx.naxis1/2.)*iidx.cdelt1
   nwyc = iidx.ycen + ((y0+ny/2.)-iidx.naxis2/2.)*iidx.cdelt2
;;   print, iidx.xcen, iidx.ycen
;;   print, iidx.naxis1, x0,x1,nx
;;   print, iidx.naxis2, y0,y1,ny
;;   print,nwxc,nwyc
   iidx.xcen   = nwxc
   iidx.ycen   = nwyc
   iidx.naxis1 = nx
   iidx.naxis2 = ny

;	adjust img min, max, avg and dev???
   pmm,data(*,*,jf)
   iidx.img_min  = min(data(*,*,jf))
   iidx.img_max  = max(data(*,*,jf))
   iidx.img_avg  = total(data(*,*,jf))/(nx*ny)
   iidx.img_dev  = stdev(data(*,*,jf))

   index(jf)    = iidx

endfor
;****************************************************************

end
