;+
; NAME:
;       VIEW_TRACE_MOSAIC
; PURPOSE:
;       View TRACE mosaic for date closest to selected date
; CATEGORY:
; CALLING SEQUENCE:
;       view_trace_mosaic,date
;       view_trace_mosaic,date,wid=500,/full
;	view_trace_mosaic,date,image=image,head=head [,/nox]
; INPUTS:
;       date		Required date (string or structure accepted)
; OPTIONAL INPUT PARAMETERS:
; KEYWORD INPUT PARAMETERS:
;       wave_len	wavelength to display  ['171' is default] 
;	width		width for display widow(s)  [400 is default]
;	full            if set, shows one windopw with full resolution
;			rather than two (full image and full resolution)
;	nox		only read fits file, does not display image
; OUTPUTS:
; OPTIONAL OUTPUT PARAMETERS:
; KEYWORD OUTPUT PARAMETERS:
;	image		full resolution image from selected fits file
;	head		header from selected fits file
; COMMON BLOCKS:
; SIDE EFFECTS:
;       creates a widget for display
; RESTRICTIONS:
;	Must have mosaics on-line ("stra*.fts" files)
;	Display closest image to the time requested
; PROCEDURE:
;
; MODIFICATION HISTORY:
;          Oct-98  RDB  Written
;
;-

pro	view_trace_mosaic, in_time, wave_len=wave_len, image=image, head=head, $
		width=width, full=full, nox=nox

;		accept different time formats
time = fmt_tim(anytim2ints(in_time(0)))

;		now deal with the keywords...
if not keyword_set(full) then full=0

wave = '171'
if keyword_set(wave_len) then wave = wave_len

wid = 400
if keyword_set(width) then wid = width

;		get the file and display it
file = trace_files(time,wave=wave,/stra)
tt = strmid(anytim(file2time(file),/vms),0,17)
box_message,'** Nearest Mosaic selected: '+tt

image = readfits(file,head)
pmm,image
title = 'TRACE Mosaic  '+wave+'A  '+tt

if not keyword_set(nox) then $
   slide_image,image,title=title,xvis=wid,yvis=wid, show_full=abs(1-full)	;, slide_window=window

return

end
